/*******************************************************************************
* File Name: VDAC_VGATE_PM.c  
* Version 1.90
*
* Description:
*  This file provides the power management source code to API for the
*  VDAC8.  
*
* Note:
*  None
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "VDAC_VGATE.h"

static VDAC_VGATE_backupStruct VDAC_VGATE_backup;


/*******************************************************************************
* Function Name: VDAC_VGATE_SaveConfig
********************************************************************************
* Summary:
*  Save the current user configuration
*
* Parameters:  
*  void  
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_VGATE_SaveConfig(void) 
{
    if (!((VDAC_VGATE_CR1 & VDAC_VGATE_SRC_MASK) == VDAC_VGATE_SRC_UDB))
    {
        VDAC_VGATE_backup.data_value = VDAC_VGATE_Data;
    }
}


/*******************************************************************************
* Function Name: VDAC_VGATE_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration.
*
* Parameters:  
*  void
*
* Return: 
*  void
*
*******************************************************************************/
void VDAC_VGATE_RestoreConfig(void) 
{
    if (!((VDAC_VGATE_CR1 & VDAC_VGATE_SRC_MASK) == VDAC_VGATE_SRC_UDB))
    {
        if((VDAC_VGATE_Strobe & VDAC_VGATE_STRB_MASK) == VDAC_VGATE_STRB_EN)
        {
            VDAC_VGATE_Strobe &= (uint8)(~VDAC_VGATE_STRB_MASK);
            VDAC_VGATE_Data = VDAC_VGATE_backup.data_value;
            VDAC_VGATE_Strobe |= VDAC_VGATE_STRB_EN;
        }
        else
        {
            VDAC_VGATE_Data = VDAC_VGATE_backup.data_value;
        }
    }
}


/*******************************************************************************
* Function Name: VDAC_VGATE_Sleep
********************************************************************************
* Summary:
*  Stop and Save the user configuration
*
* Parameters:  
*  void:  
*
* Return: 
*  void
*
* Global variables:
*  VDAC_VGATE_backup.enableState:  Is modified depending on the enable 
*  state  of the block before entering sleep mode.
*
*******************************************************************************/
void VDAC_VGATE_Sleep(void) 
{
    /* Save VDAC8's enable state */    
    if(VDAC_VGATE_ACT_PWR_EN == (VDAC_VGATE_PWRMGR & VDAC_VGATE_ACT_PWR_EN))
    {
        /* VDAC8 is enabled */
        VDAC_VGATE_backup.enableState = 1u;
    }
    else
    {
        /* VDAC8 is disabled */
        VDAC_VGATE_backup.enableState = 0u;
    }
    
    VDAC_VGATE_Stop();
    VDAC_VGATE_SaveConfig();
}


/*******************************************************************************
* Function Name: VDAC_VGATE_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration
*  
* Parameters:  
*  void
*
* Return: 
*  void
*
* Global variables:
*  VDAC_VGATE_backup.enableState:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void VDAC_VGATE_Wakeup(void) 
{
    VDAC_VGATE_RestoreConfig();
    
    if(VDAC_VGATE_backup.enableState == 1u)
    {
        /* Enable VDAC8's operation */
        VDAC_VGATE_Enable();

        /* Restore the data register */
        VDAC_VGATE_SetValue(VDAC_VGATE_Data);
    } /* Do nothing if VDAC8 was disabled before */    
}


/* [] END OF FILE */
