/*******************************************************************************
* File Name: resultIn.c  
* Version 2.10
*
* Description:
*  This file contains API to enable firmware control of a Pins component.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "resultIn.h"

/* APIs are not generated for P15[7:6] on PSoC 5 */
#if !(CY_PSOC5A &&\
	 resultIn__PORT == 15 && ((resultIn__MASK & 0xC0) != 0))


/*******************************************************************************
* Function Name: resultIn_Write
********************************************************************************
*
* Summary:
*  Assign a new value to the digital port's data output register.  
*
* Parameters:  
*  prtValue:  The value to be assigned to the Digital Port. 
*
* Return: 
*  None
*  
*******************************************************************************/
void resultIn_Write(uint8 value) 
{
    uint8 staticBits = (resultIn_DR & (uint8)(~resultIn_MASK));
    resultIn_DR = staticBits | ((uint8)(value << resultIn_SHIFT) & resultIn_MASK);
}


/*******************************************************************************
* Function Name: resultIn_SetDriveMode
********************************************************************************
*
* Summary:
*  Change the drive mode on the pins of the port.
* 
* Parameters:  
*  mode:  Change the pins to one of the following drive modes.
*
*  resultIn_DM_STRONG     Strong Drive 
*  resultIn_DM_OD_HI      Open Drain, Drives High 
*  resultIn_DM_OD_LO      Open Drain, Drives Low 
*  resultIn_DM_RES_UP     Resistive Pull Up 
*  resultIn_DM_RES_DWN    Resistive Pull Down 
*  resultIn_DM_RES_UPDWN  Resistive Pull Up/Down 
*  resultIn_DM_DIG_HIZ    High Impedance Digital 
*  resultIn_DM_ALG_HIZ    High Impedance Analog 
*
* Return: 
*  None
*
*******************************************************************************/
void resultIn_SetDriveMode(uint8 mode) 
{
	CyPins_SetPinDriveMode(resultIn_0, mode);
	CyPins_SetPinDriveMode(resultIn_1, mode);
	CyPins_SetPinDriveMode(resultIn_2, mode);
	CyPins_SetPinDriveMode(resultIn_3, mode);
	CyPins_SetPinDriveMode(resultIn_4, mode);
	CyPins_SetPinDriveMode(resultIn_5, mode);
	CyPins_SetPinDriveMode(resultIn_6, mode);
	CyPins_SetPinDriveMode(resultIn_7, mode);
}


/*******************************************************************************
* Function Name: resultIn_Read
********************************************************************************
*
* Summary:
*  Read the current value on the pins of the Digital Port in right justified 
*  form.
*
* Parameters:  
*  None
*
* Return: 
*  Returns the current value of the Digital Port as a right justified number
*  
* Note:
*  Macro resultIn_ReadPS calls this function. 
*  
*******************************************************************************/
uint8 resultIn_Read(void) 
{
    return (resultIn_PS & resultIn_MASK) >> resultIn_SHIFT;
}


/*******************************************************************************
* Function Name: resultIn_ReadDataReg
********************************************************************************
*
* Summary:
*  Read the current value assigned to a Digital Port's data output register
*
* Parameters:  
*  None 
*
* Return: 
*  Returns the current value assigned to the Digital Port's data output register
*  
*******************************************************************************/
uint8 resultIn_ReadDataReg(void) 
{
    return (resultIn_DR & resultIn_MASK) >> resultIn_SHIFT;
}


/* If Interrupts Are Enabled for this Pins component */ 
#if defined(resultIn_INTSTAT) 

    /*******************************************************************************
    * Function Name: resultIn_ClearInterrupt
    ********************************************************************************
    * Summary:
    *  Clears any active interrupts attached to port and returns the value of the 
    *  interrupt status register.
    *
    * Parameters:  
    *  None 
    *
    * Return: 
    *  Returns the value of the interrupt status register
    *  
    *******************************************************************************/
    uint8 resultIn_ClearInterrupt(void) 
    {
        return (resultIn_INTSTAT & resultIn_MASK) >> resultIn_SHIFT;
    }

#endif /* If Interrupts Are Enabled for this Pins component */ 

#endif /* CY_PSOC5A... */

    
/* [] END OF FILE */
