/*******************************************************************************
* File Name: sel_High_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "sel_High.h"

/* Check for removal by optimization */
#if !defined(sel_High_Sync_ctrl_reg__REMOVED)

static sel_High_BACKUP_STRUCT  sel_High_backup = {0u};

    
/*******************************************************************************
* Function Name: sel_High_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void sel_High_SaveConfig(void) 
{
    sel_High_backup.controlState = sel_High_Control;
}


/*******************************************************************************
* Function Name: sel_High_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void sel_High_RestoreConfig(void) 
{
     sel_High_Control = sel_High_backup.controlState;
}


/*******************************************************************************
* Function Name: sel_High_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void sel_High_Sleep(void) 
{
    sel_High_SaveConfig();
}


/*******************************************************************************
* Function Name: sel_High_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void sel_High_Wakeup(void)  
{
    sel_High_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
