/*******************************************************************************
* File Name: sel_Low_PM.c
* Version 1.80
*
* Description:
*  This file contains the setup, control, and status commands to support 
*  the component operation in the low power mode. 
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "sel_Low.h"

/* Check for removal by optimization */
#if !defined(sel_Low_Sync_ctrl_reg__REMOVED)

static sel_Low_BACKUP_STRUCT  sel_Low_backup = {0u};

    
/*******************************************************************************
* Function Name: sel_Low_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void sel_Low_SaveConfig(void) 
{
    sel_Low_backup.controlState = sel_Low_Control;
}


/*******************************************************************************
* Function Name: sel_Low_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the control register value.
*
* Parameters:
*  None
*
* Return:
*  None
*
*
*******************************************************************************/
void sel_Low_RestoreConfig(void) 
{
     sel_Low_Control = sel_Low_backup.controlState;
}


/*******************************************************************************
* Function Name: sel_Low_Sleep
********************************************************************************
*
* Summary:
*  Prepares the component for entering the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void sel_Low_Sleep(void) 
{
    sel_Low_SaveConfig();
}


/*******************************************************************************
* Function Name: sel_Low_Wakeup
********************************************************************************
*
* Summary:
*  Restores the component after waking up from the low power mode.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void sel_Low_Wakeup(void)  
{
    sel_Low_RestoreConfig();
}

#endif /* End check for removal by optimization */


/* [] END OF FILE */
